from multiprocessing import Process, Queue
import os, glob, json, time, signal

from indy_utils.indy_shm import *
from indy_utils import indydcp_client as client


# Requirement: pyarmor

indy = client.IndyDCPClient("localhost", "NRMK-Indy7")
indy.connect()
indy_master = IndyShmCommand()


def main_process():
    iidx = 1
    while True:
        iidx += 1
        tic = time.time()

        time.sleep(0.1)   # 100ms

        j_pos = indy_master.get_joint_pos()
        t_pos = indy_master.get_task_pos()
        ai = indy_master.get_ai()
        ao = indy_master.get_ao()
        di = indy_master.get_di()
        do = indy_master.get_do()

        print("=== Monitoring ===")
        print("Analog input: {}".format(ai))
        print("Analog output: {}".format(ao))
        print("Digital input: {}".format(di))
        print("Digital input: {}".format(do))
        print("Joint pos: {}".format(j_pos))
        print("Task pos: {}".format(t_pos))

        if do[0] == 1:
            indy.stop_motion()
        elif do[1] == 1:
            if not indy.is_busy():
                indy.go_home()
        elif do[2] == 1:
            if not indy.is_busy():
                indy.go_zero()


        toc = time.time()
        print("Elapsed time: {}ms ({} cnt)".format((toc - tic) * 1000, iidx))


def sig_handler(signum, frame):
    global pid_list
    indy.disconnect()
    print('SIGNAL RECEIVED:', signum)
    sys.exit(-1)


if __name__ == "__main__":
    q = Queue()
    p1 = Process(target=main_process)
    pid_list = [p1.pid ]

    print("SIGNAL Handler for TERM, INT")
    signal.signal(signal.SIGTERM, sig_handler)
    signal.signal(signal.SIGINT, sig_handler)

    print("Start process")
    p1.start()
    time.sleep(0.01)
    if True or p1.is_alive():
        while True:
            time.sleep(1)
    q.close()
    q.join_thread()
    p1.join()

    print("Finish")



